==> ejc-bid-api-3.0.0-20211118.090414-10-sources.jar: com/ejianc/business/bid/vo/StopApplyVO.java <==
package com.ejianc.business.bid.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 投标停止申请
 * 
 * @author generator
 * 
 */
@ApiModel("投标停止申请")
public class StopApplyVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("投标报名ID")
    private java.lang.Long bidEnrollId;
    @ApiModelProperty("单据编码")
    private java.lang.String billCode;
    @ApiModelProperty("工程名称")
    private java.lang.String engineeringName;
    @ApiModelProperty("申请日期")
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    private java.util.Date applyDate;
    @ApiModelProperty("终止原因")
    private java.lang.String stopReason;
    @ApiModelProperty("备注")
    private java.lang.String remark;
    @ApiModelProperty("单据状态（审批必须字段）")
    private java.lang.Integer billState;
    @ApiModelProperty("所属组织")
    private java.lang.Long orgId;
    @ApiModelProperty("所属组织名称")
    private java.lang.String orgName;
    

    /**
     * 投标报名ID
     */
    public java.lang.Long getBidEnrollId() {
        return bidEnrollId;
    }

    /**
     * 投标报名ID
     */
    public void setBidEnrollId(java.lang.Long bidEnrollId) {
        this.bidEnrollId = bidEnrollId;
    }
    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 工程名称
     */
    public java.lang.String getEngineeringName() {
        return engineeringName;
    }

    /**
     * 工程名称
     */
    public void setEngineeringName(java.lang.String engineeringName) {
        this.engineeringName = engineeringName;
    }
    /**
     * 申请日期
     */
    public java.util.Date getApplyDate() {
        return applyDate;
    }

    /**
     * 申请日期
     */
    public void setApplyDate(java.util.Date applyDate) {
        this.applyDate = applyDate;
    }
    /**
     * 终止原因
     */
    public java.lang.String getStopReason() {
        return stopReason;
    }

    /**
     * 终止原因
     */
    public void setStopReason(java.lang.String stopReason) {
        this.stopReason = stopReason;
    }
    /**
     * 备注
     */
    public java.lang.String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(java.lang.String remark) {
        this.remark = remark;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 所属组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    
}

==> ejc-bid-api-3.0.0-20211118.091341-11-sources.jar: com/ejianc/business/bid/vo/StopApplyVO.java <==
package com.ejianc.business.bid.vo;

import java.util.Date;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 投标停止申请
 * 
 * @author generator
 * 
 */
@ApiModel("投标停止申请")
public class StopApplyVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("投标报名ID")
    private java.lang.Long bidEnrollId;
    @ApiModelProperty("单据编码")
    private java.lang.String billCode;
    @ApiModelProperty("工程名称")
    private java.lang.String engineeringName;
    @ApiModelProperty("申请日期")
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private java.util.Date applyDate;
    @ApiModelProperty("终止原因")
    private java.lang.String stopReason;
    @ApiModelProperty("备注")
    private java.lang.String remark;
    @ApiModelProperty("编制人")
    private Integer employeeId;
    @ApiModelProperty("编制人名称")
    private String employeeName;
    @ApiModelProperty("编制日期")
    private java.util.Date bill_date;
    @ApiModelProperty("单据状态（审批必须字段）")
    private java.lang.Integer billState;
    @ApiModelProperty("所属组织")
    private java.lang.Long orgId;
    @ApiModelProperty("所属组织名称")
    private java.lang.String orgName;
    

    /**
     * 投标报名ID
     */
    public java.lang.Long getBidEnrollId() {
        return bidEnrollId;
    }

    /**
     * 投标报名ID
     */
    public void setBidEnrollId(java.lang.Long bidEnrollId) {
        this.bidEnrollId = bidEnrollId;
    }
    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 工程名称
     */
    public java.lang.String getEngineeringName() {
        return engineeringName;
    }

    /**
     * 工程名称
     */
    public void setEngineeringName(java.lang.String engineeringName) {
        this.engineeringName = engineeringName;
    }
    /**
     * 申请日期
     */
    public java.util.Date getApplyDate() {
        return applyDate;
    }

    /**
     * 申请日期
     */
    public void setApplyDate(java.util.Date applyDate) {
        this.applyDate = applyDate;
    }
    /**
     * 终止原因
     */
    public java.lang.String getStopReason() {
        return stopReason;
    }

    /**
     * 终止原因
     */
    public void setStopReason(java.lang.String stopReason) {
        this.stopReason = stopReason;
    }
    /**
     * 备注
     */
    public java.lang.String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(java.lang.String remark) {
        this.remark = remark;
    }
    /**
     * 编制人
     */
    public Integer getEmployeeId() {
        return employeeId;
    }
    /**
     * 编制人
     */
    public void setEmployeeId(Integer employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 编制人名称
     */
    public String getEmployeeName() {
        return employeeName;
    }
    /**
     * 编制人名称
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 编制时间
     */
    public Date getBill_date() {
        return bill_date;
    }
    /**
     * 编制时间
     */
    public void setBill_date(Date bill_date) {
        this.bill_date = bill_date;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 所属组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    
}
